@@ -153,10 +153,8 @@ class ResultsWindow(QMainWindow, Ui_ResultsWindow):
                 self.history[len(self.history)-1]['index'] = self.index
                 populate_results(url, 0, ui.results, self, True)
             else:
-                if os.path.isfile('/opt/kmplayer/bin/kmplayer'):
-                    os.system('/opt/kmplayer/bin/kmplayer %s &' % ui.results[self.index].get('URL'))
-                elif os.path.isfile('/usr/bin/kmplayer'):
-                    os.system('/usr/bin/kmplayer %s &' % ui.results[self.index].get('URL'))
+                if os.path.isfile('/opt/kmplayer/bin/kmplayer') or os.path.isfile('/usr/bin/kmplayer'):
+                    os.system('/usr/bin/dbus-send --print-reply --dest=com.nokia.kmplayer /com/nokia/kmplayer com.nokia.kmplayer.mime_open string:%s' % ui.results[self.index].get('URL'))
                 elif os.path.isfile('/Applications/VLC.app/Contents/MacOS/VLC'):
                     os.system('/Applications/VLC.app/Contents/MacOS/VLC %s &' % ui.results[self.index].get('URL'))
                 elif os.path.isfile('c:/program files/VideoLAN/vlc/vlc.exe'):
